/** ###################################################################
**     Filename  : Events.C
**     Project   : BP_hala
**     Processor : MC9S08QE32CWL
**     Component : Events
**     Version   : Driver 01.02
**     Compiler  : CodeWarrior HCS08 C Compiler
**     Date/Time : 17.4.2012, 17:59
**     Abstract  :
**         This is user's event module.
**         Put your event handler code here.
**     Settings  :
**     Contents  :
**         AD1_OnEnd - void AD1_OnEnd(void);
**
** ###################################################################*/
/* MODULE Events */


#include "Cpu.h"
#include "Events.h"

#define perioda_pwm (100)           //definice periody pro PWM 

extern int hodnota_okruh1_l;        //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 1. okruh - linearizovana
extern int hodnota_okruh2_l;        //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 2. okruh - linearizovana
extern int hodnota_okruh3_l;        //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 3. okruh - linearizovana
extern int hodnota_okruh4_l;        //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 4. okruh - linearizovana
extern bool prevod_adc;             //priznak uspesneho prevedu od adc
extern bool prevod_linearizace;     //priznak uspesnoho prevodu linearizace

int hodnota_okruh1=0;               //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 1. okruh - korektni
int hodnota_okruh2=0;               //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 2. okruh - korektni
int hodnota_okruh3=0;               //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 3. okruh - korektni
int hodnota_okruh4=0;               //hodnota v rozmezi 0-100, nactena z A/D prevodniku pro 4. okruh - korektni

int citac1=0;                       //promenna pro citani poctu preruseni pro 1. okruh
int citac2=0;                       //promenna pro citani poctu preruseni pro 2. okruh
int citac3=0;                       //promenna pro citani poctu preruseni pro 3. okruh
int citac4=0;                       //promenna pro citani poctu preruseni pro 4. okruh
int sirka_pulsu1=0;                 //promenna pro ulozeni prevedene hodnoty z A/D prevodniku pro 1. okruh
int sirka_pulsu2=0;                 //promenna pro ulozeni prevedene hodnoty z A/D prevodniku pro 2. okruh
int sirka_pulsu3=0;                 //promenna pro ulozeni prevedene hodnoty z A/D prevodniku pro 3. okruh
int sirka_pulsu4=0;                 //promenna pro ulozeni prevedene hodnoty z A/D prevodniku pro 4. okruh

/* User includes (#include below this line is not maintained by Processor Expert) */

/*
** ===================================================================
**     Event       :  AD1_OnEnd (module Events)
**
**     Component   :  AD1 [ADC]
**     Description :
**         This event is called after the measurement (which consists
**         of <1 or more conversions>) is/are finished.
**         The event is available only when the <Interrupt
**         service/event> property is enabled.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void AD1_OnEnd(void)
{
  /* Write your code here ... */
}


/*
** ===================================================================
**     Event       :  TI1_OnInterrupt (module Events)
**
**     Component   :  TI1 [TimerInt]
**     Description :
**         When a timer interrupt occurs this event is called (only
**         when the component is enabled - <Enable> and the events are
**         enabled - <EnableEvent>). This event is enabled only if a
**         <interrupt service/event> is enabled.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void TI1_OnInterrupt(void)
{
  /* Write your code here ... */
  
  //aby nenastal spatny zapis do promennych, prepsani pokud probehly oba prevody
  if((prevod_adc==1)&&(prevod_linearizace==1)){                  
    hodnota_okruh1=hodnota_okruh1_l;    //pro prvni okruh
    hodnota_okruh2=hodnota_okruh2_l;    //pro druhy okruh
    hodnota_okruh3=hodnota_okruh3_l;    //pro treti okruh
    hodnota_okruh4=hodnota_okruh4_l;    //pro ctvrty okruh
    prevod_adc=0;                       //nulovani priznaku prevedeni od ADC
    prevod_linearizace=0;               //nulovani priznaku kompletni linearizace
  } 
  
  //====================OKRUH1==========================================	 	 
  if ((citac1 == 0) && (sirka_pulsu1 > 0))  	//zacatek pulsu?
  		PTCD_PTCD0 = 1;		            //zarovky1 on
	
  if ((citac1 == sirka_pulsu1) && (sirka_pulsu1 < perioda_pwm)) //konec pulsu?
    		PTCD_PTCD0 = 0;		          //zarovky1 off
	   
	citac1++;
	  
  if (citac1 == perioda_pwm) {      //konec periody?
 		  citac1=0;	                    //nulovani citace
 		  sirka_pulsu1=hodnota_okruh1;  //nastavovani sirky pulsu na konci periody, at nezablikne  
  }

  //====================OKRUH2==========================================
  if ((citac2 == 0) && (sirka_pulsu2 > 0))  	//zacatek pulsu?
  		PTCD_PTCD1 = 1;		            //zarovky2 on
	
  if ((citac2 == sirka_pulsu2) && (sirka_pulsu2 < perioda_pwm)) //konec pulsu?
    		PTCD_PTCD1 = 0;		          //zarovky2 off
	   
	citac2++;
	  
  if (citac2 == perioda_pwm) {      //konec periody?
 		  citac2=0;	                    //nulovani citace
 		  sirka_pulsu2=hodnota_okruh2;  //nastavovani sirky pulsu na konci periody, at nezablikne  
  }   

  //====================OKRUH3==========================================
  if ((citac3 == 0) && (sirka_pulsu3 > 0))  	//zacatek pulsu?
  		PTCD_PTCD2 = 1;		            //zarovky3 on
	
  if ((citac3 == sirka_pulsu3) && (sirka_pulsu3 < perioda_pwm)) //konec pulsu?
    		PTCD_PTCD2 = 0;		          //zarovky3 off
	   
	citac3++;
	  
  if (citac3 == perioda_pwm) {      //konec periody?
 		  citac3=0;	                    //nulovani citace
 		  sirka_pulsu3=hodnota_okruh3;  //nastavovani sirky pulsu na konci periody, at nezablikne  
  } 

  //====================OKRUH4==========================================
  if ((citac4 == 0) && (sirka_pulsu4 > 0))  	//zacatek pulsu?
  		PTCD_PTCD3 = 1;		            //zarovky4 on
	
  if ((citac4 == sirka_pulsu4) && (sirka_pulsu4 < perioda_pwm)) //konec pulsu?
    		PTCD_PTCD3 = 0;		          //zarovky4 off
	   
	citac4++;
	  
  if (citac4 == perioda_pwm) {      //konec periody?
 		  citac4=0;	                    //nulovani citace
 		  sirka_pulsu4=hodnota_okruh4;  //nastavovani sirky pulsu na konci periody, at nezablikne  
  }

}

/* END Events */

/*
** ###################################################################
**
**     This file was created by Processor Expert 3.07 [04.34]
**     for the Freescale HCS08 series of microcontrollers.
**
** ###################################################################
*/
